@@ -774,8 +774,8 @@ namespace Rstats {
     SV* new_array(SV*);
     void set_vector(SV*, SV*, Rstats::Vector*);
     Rstats::Vector* get_vector(SV*, SV*);
-    void set_dim(SV*, SV*, Rstats::Vector*);
-    Rstats::Vector* get_dim(SV*, SV*);
+    void set_dim_vector(SV*, SV*, Rstats::Vector*);
+    Rstats::Vector* get_dim_vector(SV*, SV*);
     SV* c(SV*, SV*);
     SV* to_c(SV*, SV*);
     SV* new_null(SV*); /* NULL */
@@ -789,6 +789,17 @@ namespace Rstats {
     SV* new_complex(SV*, SV*);
     SV* new_integer(SV*, SV*);
     SV* new_logical(SV*, SV*);
+    SV* pi(SV*);
+    SV* is_vector(SV*, SV*);
+    SV* length_value(SV*, SV*);
+    SV* values(SV*, SV*);
+    SV* set_dim(SV*, SV*, SV*);
+    SV* get_dim(SV*, SV*);
+    SV* is_matrix(SV*, SV*);
+    SV* is_array(SV*, SV*);
+    SV* is_numeric(SV*, SV*);
+    SV* type(SV*, SV*);
+    IV to_bool(SV*, SV*);
   }
 }
 
